From 5c18d6384a55a4bc1e641ebe52dc69528e43b50d Mon Sep 17 00:00:00 2001
From: myqnrrhmn
Date: Tue, 8 Jul 2025 10:36:18 +0700
Subject: [PATCH] chore: all kerjasama text to kerja sama
---
app/Exports/CooperationArchiveExport.php | 2 +-
app/Exports/CooperationCompletionExport.php | 2 +-
app/Exports/CooperationExport.php | 2 +-
app/Exports/ReportExport.php | 2 +-
.../CooperationArchiveController.php | 2 +-
.../CooperationCompletionController.php | 36 +++++-----
.../CooperationRequestController.php | 52 +++++++--------
.../Dashboard/DatatableController.php | 30 ++++-----
.../Dashboard/MediaCooperationController.php | 66 +++++++++----------
.../Dashboard/MediaOrderController.php | 16 ++---
.../Dashboard/OverviewController.php | 8 +--
.../Dashboard/ReportController.php | 10 +--
app/Http/Requests/CooperationRequest.php | 2 +-
.../2025_02_27_064111_app_settings.php | 2 +-
.../dashboard/announcements/create.blade.php | 2 +-
.../dashboard/announcements/edit.blade.php | 2 +-
.../dashboard/content-recaps/create.blade.php | 2 +-
.../dashboard/content-recaps/edit.blade.php | 2 +-
.../cooperation-archives/index.blade.php | 4 +-
.../cooperation-completions/index.blade.php | 2 +-
.../index/process.blade.php | 4 +-
.../index/show.blade.php | 2 +-
.../cooperation-completions/reject.blade.php | 2 +-
.../cooperation-completions/show.blade.php | 2 +-
.../create-proposal.blade.php | 4 +-
.../media-proposals/edit.blade.php | 2 +-
.../media-proposals/index.blade.php | 2 +-
.../media-proposals/show.blade.php | 2 +-
.../cooperation-requests/reject.blade.php | 2 +-
.../cooperation-requests/show.blade.php | 2 +-
.../media-cooperations/create.blade.php | 2 +-
.../media-cooperations/edit.blade.php | 2 +-
.../media-cooperations/index.blade.php | 4 +-
.../media-proposals/reject.blade.php | 2 +-
.../media-proposals/show.blade.php | 2 +-
.../completions/index-media.blade.php | 12 ++--
.../processes/cooperations/index.blade.php | 6 +-
.../processes/tab.blade.php | 2 +-
.../media-cooperations/show.blade.php | 2 +-
.../dashboard/overview/index-copy.blade.php | 2 +-
.../views/dashboard/overview/index.blade.php | 2 +-
.../views/dashboard/reports/index.blade.php | 2 +-
.../partials/app/calendars/admin.blade.php | 4 +-
.../partials/app/calendars/media.blade.php | 6 +-
.../partials/dashboard/sidebar.blade.php | 8 +--
45 files changed, 164 insertions(+), 164 deletions(-)
diff --git a/app/Exports/CooperationArchiveExport.php b/app/Exports/CooperationArchiveExport.php
index cc9376e..b20cfc6 100644
--- a/app/Exports/CooperationArchiveExport.php
+++ b/app/Exports/CooperationArchiveExport.php
@@ -83,7 +83,7 @@ public function headings(): array
{
return [
['Data Rekap Konten', '', '', '', '', ''],
- ['NO', 'Nama Kerjasama', 'Taanggal Mulai', 'Tanggal Selesai', 'Deskripsi', 'Dibuat Pada']
+ ['NO', 'Nama Kerja Sama', 'Taanggal Mulai', 'Tanggal Selesai', 'Deskripsi', 'Dibuat Pada']
];
}
diff --git a/app/Exports/CooperationCompletionExport.php b/app/Exports/CooperationCompletionExport.php
index 7d8e1d2..d8219ef 100644
--- a/app/Exports/CooperationCompletionExport.php
+++ b/app/Exports/CooperationCompletionExport.php
@@ -95,7 +95,7 @@ public function headings(): array
{
return [
['Penyelesaian Kerja Sama', '', '', '', '', ''],
- ['NO', 'Nama Kerjasama', 'Media', 'Perusahaan', 'Tanggal Upload', 'Status']
+ ['NO', 'Nama Kerja Sama', 'Media', 'Perusahaan', 'Tanggal Upload', 'Status']
];
}
diff --git a/app/Exports/CooperationExport.php b/app/Exports/CooperationExport.php
index 579784d..ade99a5 100644
--- a/app/Exports/CooperationExport.php
+++ b/app/Exports/CooperationExport.php
@@ -77,7 +77,7 @@ public function headings(): array
{
return [
['Data Rekap Konten', '', '', '', '', '', ''],
- ['NO', 'Nama Kerjasama', 'Tanggal Mulai', 'Tanggal Selesai', 'Deskripsi', 'Media', 'Dibuat Pada']
+ ['NO', 'Nama Kerja Sama', 'Tanggal Mulai', 'Tanggal Selesai', 'Deskripsi', 'Media', 'Dibuat Pada']
];
}
diff --git a/app/Exports/ReportExport.php b/app/Exports/ReportExport.php
index 29a1a13..768de4a 100644
--- a/app/Exports/ReportExport.php
+++ b/app/Exports/ReportExport.php
@@ -97,7 +97,7 @@ public function headings(): array
{
return [
['Laporan Bukti Tayang', '', '', '', '', '', '', ''],
- ['NO', 'Nama Kerjasama', 'Media', 'Perusahaan', 'Tanggal Upload', 'Tanggal Melaporkan', 'Status']
+ ['NO', 'Nama Kerja Sama', 'Media', 'Perusahaan', 'Tanggal Upload', 'Tanggal Melaporkan', 'Status']
];
}
diff --git a/app/Http/Controllers/Dashboard/CooperationArchiveController.php b/app/Http/Controllers/Dashboard/CooperationArchiveController.php
index e9da3bb..9a43dd1 100644
--- a/app/Http/Controllers/Dashboard/CooperationArchiveController.php
+++ b/app/Http/Controllers/Dashboard/CooperationArchiveController.php
@@ -11,7 +11,7 @@ class CooperationArchiveController extends Controller
{
public function index(Request $request){
return view('dashboard.cooperation-archives.index', [
- 'title' => 'Arsip Kerjasama',
+ 'title' => 'Arsip Kerja Sama',
'date' => $request->input('date', null),
'month' => $request->input('month', null),
'year' => $request->input('year', null),
diff --git a/app/Http/Controllers/Dashboard/CooperationRequestController.php b/app/Http/Controllers/Dashboard/CooperationRequestController.php
index 60a268d..3824403 100644
--- a/app/Http/Controllers/Dashboard/CooperationRequestController.php
+++ b/app/Http/Controllers/Dashboard/CooperationRequestController.php
@@ -16,7 +16,7 @@ class CooperationRequestController extends Controller
{
public function index(){
return view('dashboard.cooperation-requests.index', [
- 'title' => 'Ajuan Kerjasama'
+ 'title' => 'Ajuan Kerja Sama'
]);
}
@@ -28,7 +28,7 @@ public function show($id){
->first()->pivot;
return view('dashboard.cooperation-requests.show', [
- 'title' => 'Tolak Kerjasama',
+ 'title' => 'Tolak Kerja Sama',
'cooperation' => $cooperation,
'mediaCooperationPivot' => $mediaCooperationPivot
]);
@@ -36,7 +36,7 @@ public function show($id){
public function mediaProposal(){
return view('dashboard.cooperation-requests.media-proposals.index',[
- 'title' => 'Ajuan Kerjasama Saya'
+ 'title' => 'Ajuan Kerja Sama Saya'
]);
}
@@ -44,7 +44,7 @@ public function mediaProposalShow($id){
$proposal = CooperationProposal::with(['cooperation', 'media', 'journalists'])->findOrFail(decrypt_id($id));
return view('dashboard.cooperation-requests.media-proposals.show',[
- 'title' => 'Detail Ajuan Kerjasama',
+ 'title' => 'Detail Ajuan Kerja Sama',
'proposal' => $proposal
]);
}
@@ -74,8 +74,8 @@ public function accept(Request $request, $id){
// Announcements
$announcementData = [
- 'headline' => 'Ajuan Kerjasama '.$cooperation->name.' diterima oleh media '.$mediaCooperation->name. '',
- 'content' => 'Ajuan Kerjasama '.$cooperation->name.' telah diterima oleh media '.$mediaCooperation->name.'
',
+ 'headline' => 'Ajuan Kerja Sama '.$cooperation->name.' diterima oleh media '.$mediaCooperation->name. '',
+ 'content' => 'Ajuan Kerja Sama '.$cooperation->name.' telah diterima oleh media '.$mediaCooperation->name.'
',
'enhancer_id' => Auth::id()
];
@@ -88,12 +88,12 @@ public function accept(Request $request, $id){
// End Announcements
if ($affectedRows > 0) {
- return redirect()->back()->with('success-status', 'Berhasil menerima kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menerima kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal menerima kerjasama.');
+ return redirect()->back()->with('failed-status', 'Gagal menerima kerja sama.');
}
} else {
- return redirect()->back()->with('failed-status', 'Kerjasama sudah diterima sebelumnya.');
+ return redirect()->back()->with('failed-status', 'Kerja Sama sudah diterima sebelumnya.');
}
}catch(\Exception $e){
Log::error("CooperationRequest (accept): ". $e);
@@ -110,7 +110,7 @@ public function createProposal($id){
->first()->pivot;
return view('dashboard.cooperation-requests.create-proposal', [
- 'title' => 'Ajukan Kerjasama',
+ 'title' => 'Ajukan Kerja Sama',
'user' => Auth::user(),
'cooperation' => $cooperation,
'mediaCooperationPivot' => $mediaCooperationPivot
@@ -131,8 +131,8 @@ public function storeProposal(JournalistCooperationProposalRequest $request, $id
// Announcements
$announcementData = [
- 'headline' => 'Media '.Auth::user()->company->media->name.' telah mengirimkan formulir pengajuan kerjasama '.$cooperation->name. '',
- 'content' => 'Media '.Auth::user()->company->media->name.' telah mengirimkan formulir pengajuan kerjasama '.$cooperation->name. ' pada '.idn_date($createdCooperationProposal->created_at, 'l, d F Y H:i').'',
+ 'headline' => 'Media '.Auth::user()->company->media->name.' telah mengirimkan formulir pengajuan kerja sama '.$cooperation->name. '',
+ 'content' => 'Media '.Auth::user()->company->media->name.' telah mengirimkan formulir pengajuan kerja sama '.$cooperation->name. ' pada '.idn_date($createdCooperationProposal->created_at, 'l, d F Y H:i').'',
'enhancer_id' => Auth::id()
];
@@ -150,10 +150,10 @@ public function storeProposal(JournalistCooperationProposalRequest $request, $id
}catch(\Exception $e){
Log::info("ERROR Cooperation Proposals: ". $e);
- return redirect()->back()->with('failed-status', 'Gagal melakukan pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal melakukan pengajuan kerja sama');
}
- return redirect()->route('dashboard.cooperations.requests.index')->with('success-status', 'Berhasil melakukan pengajuan kerjasama.');
+ return redirect()->route('dashboard.cooperations.requests.index')->with('success-status', 'Berhasil melakukan pengajuan kerja sama.');
}
public function reject($id){
@@ -164,7 +164,7 @@ public function reject($id){
->first()->pivot;
return view('dashboard.cooperation-requests.reject', [
- 'title' => 'Tolak Kerjasama',
+ 'title' => 'Tolak Kerja Sama',
'cooperation' => $cooperation,
'mediaCooperationPivot' => $mediaCooperationPivot
]);
@@ -202,8 +202,8 @@ public function rejectAction(Request $request, $id){
// Announcements
$announcementData = [
- 'headline' => 'Ajuan Kerjasama '.$cooperation->name.' ditolak oleh media '.$mediaCooperation->name. '',
- 'content' => 'Ajuan Kerjasama '.$cooperation->name.' ditolak oleh media '.$mediaCooperation->name.'
+ 'headline' => 'Ajuan Kerja Sama '.$cooperation->name.' ditolak oleh media '.$mediaCooperation->name. '',
+ 'content' => 'Ajuan Kerja Sama '.$cooperation->name.' ditolak oleh media '.$mediaCooperation->name.'
Alasan:
'.$validatedData['rejection_reason'].'
',
'enhancer_id' => Auth::id()
@@ -218,12 +218,12 @@ public function rejectAction(Request $request, $id){
// End Announcements
if ($affectedRows > 0) {
- return redirect()->back()->with('success-status', 'Berhasil menolak kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menolak kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal menolak kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menolak kerja sama');
}
} else {
- return redirect()->back()->with('failed-status', 'Kerjasama sudah ditolak sebelumnya.');
+ return redirect()->back()->with('failed-status', 'Kerja sama sudah ditolak sebelumnya.');
}
}catch(\Exception $e){
Log::error("CooperationRequest (rejectAction): ". $e);
@@ -236,7 +236,7 @@ public function editProposal($id){
$proposal = CooperationProposal::with(['cooperation', 'media', 'journalists'])->findOrFail(decrypt_id($id));
return view('dashboard.cooperation-requests.media-proposals.edit',[
- 'title' => 'Ubah Ajuan Kerjasama',
+ 'title' => 'Ubah Ajuan Kerja Sama',
'proposal' => $proposal,
'selectedJournalists' => $proposal->journalists->pluck('id')->toArray()
]);
@@ -264,13 +264,13 @@ public function updateProposal(JournalistCooperationProposalRequest $request, $i
}
if ($proposal->journalists()->count() > 0) {
- return redirect()->back()->with('success-status', 'Berhasil mengubah pengajuan kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil mengubah pengajuan kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal mengubah pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal mengubah pengajuan kerja sama');
}
}catch(\Exception $e){
Log::error("CooperationRequest (updateProposal): ". $e);
- return redirect()->back()->with('failed-status', 'Gagal mengubah pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal mengubah pengajuan kerja sama');
}
}
@@ -282,10 +282,10 @@ public function destroyProposal($id){
$cooperationProposal->delete();
- return response()->json(['message' => 'Berhasil menghapus ajuan kerjasama.']);
+ return response()->json(['message' => 'Berhasil menghapus ajuan kerja sama.']);
} catch (\Exception $e) {
Log::error("CooperationRequest (destroyProposal): ". $e);
- return response()->json(['message' => 'Gagal menghapus ajuan kerjasama.'], 500);
+ return response()->json(['message' => 'Gagal menghapus ajuan kerja sama.'], 500);
}
}
}
diff --git a/app/Http/Controllers/Dashboard/MediaCooperationController.php b/app/Http/Controllers/Dashboard/MediaCooperationController.php
index 6c73ebe..df6c5e5 100644
--- a/app/Http/Controllers/Dashboard/MediaCooperationController.php
+++ b/app/Http/Controllers/Dashboard/MediaCooperationController.php
@@ -21,7 +21,7 @@ class MediaCooperationController extends Controller
{
public function index(Request $request){
return view('dashboard.media-cooperations.index', [
- 'title' => 'Kerjasama',
+ 'title' => 'Kerja Sama',
'date' => $request->input('date', null),
'month' => $request->input('month', null),
'year' => $request->input('year', null),
@@ -30,7 +30,7 @@ public function index(Request $request){
public function create(){
return view('dashboard.media-cooperations.create', [
- 'title' => 'Tambah Kerjasama',
+ 'title' => 'Tambah Kerja Sama',
'media' => Media::all()
]);
}
@@ -68,8 +68,8 @@ public function store(CooperationRequest $request){
}
$announcementData = [
- 'headline' => 'Ajuan kerjasama baru: '. $createdCooperation->name. '',
- 'content' => 'Kerjasama: '. $validatedData['name']. '
+ 'headline' => 'Ajuan kerja sama baru: '. $createdCooperation->name. '',
+ 'content' => 'Kerja Sama: '. $validatedData['name']. '
Periode Pengajuan: '.idn_date($createdCooperation->start_date).' s.d. '.idn_date($createdCooperation->end_date).'
Deskripsi:
'.$createdCooperation->description.'
@@ -85,20 +85,20 @@ public function store(CooperationRequest $request){
});
if ($createdCooperation->media()->count() > 0) {
- return redirect()->route('dashboard.cooperations.index')->with('success-status', 'Berhasil menambahkan kerjasama.');
+ return redirect()->route('dashboard.cooperations.index')->with('success-status', 'Berhasil menambahkan kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal menambahkan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menambahkan kerja sama');
}
}catch(\Exception $e){
Log::info("ERROR (Cooperation): ". $e);
- return redirect()->back()->with('failed-status', 'Gagal menambahkan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menambahkan kerja sama');
}
}
public function edit($id){
$cooperation = Cooperation::with(['media'])->findOrFail(decrypt_id($id));
return view('dashboard.media-cooperations.edit', [
- 'title' => 'Ubah Kerjasama',
+ 'title' => 'Ubah Kerja Sama',
'cooperation' => $cooperation,
'media' => Media::all(),
'selectedMediaIds' => $cooperation->media->pluck('id')->toArray()
@@ -138,8 +138,8 @@ public function update(CooperationRequest $request, $id){
}
$announcementData = [
- 'headline' => 'Admin melakukan pembaruan pada ajuan kerjasama '. $oldCooperationName. '',
- 'content' => '
Admin telah melakukan pembaruan pada kerjasama ' . $oldCooperationName . '.
+ 'headline' => 'Admin melakukan pembaruan pada ajuan kerja sama '. $oldCooperationName. '',
+ 'content' => '
Admin telah melakukan pembaruan pada kerja sama ' . $oldCooperationName . '.
Mohon untuk segera meninjau perubahan tersebut
',
'enhancer_id' => Auth::id()
@@ -149,12 +149,12 @@ public function update(CooperationRequest $request, $id){
// End Announcements
if ($cooperation->media()->count() > 0) {
- return redirect()->back()->with('success-status', 'Berhasil mengubah kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil mengubah kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal mengubah kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal mengubah kerja sama');
}
}catch(\Exception $e){
- return redirect()->back()->with('failed-status', 'Gagal mengubah kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal mengubah kerja sama');
}
}
@@ -163,7 +163,7 @@ public function show($id){
$mediaCooperation = Cooperation::with(['media'])->findOrFail(decrypt_id($id));
return view('dashboard.media-cooperations.show', [
- 'title' => 'Detail Kerjasama',
+ 'title' => 'Detail Kerja Sama',
'mediaCooperation' => $mediaCooperation
]);
}
@@ -205,7 +205,7 @@ public function mediaProposal($id){
$mediaCooperation = Cooperation::with(['media'])->findOrFail(decrypt_id($id));
return view('dashboard.media-cooperations.media-proposals.index', [
- 'title' => 'Data Pengajuan Kerjasama',
+ 'title' => 'Data Pengajuan Kerja Sama',
'mediaCooperation' => $mediaCooperation
]);
}
@@ -214,7 +214,7 @@ public function mediaProposalShow($id, $proposalId){
$proposal = CooperationProposal::with(['cooperation', 'media', 'journalists'])->findOrFail(decrypt_id($proposalId));
return view('dashboard.media-cooperations.media-proposals.show',[
- 'title' => 'Detail Ajuan Kerjasama',
+ 'title' => 'Detail Ajuan Kerja Sama',
'proposal' => $proposal
]);
}
@@ -230,9 +230,9 @@ public function mediaProposalAccept($id, $proposalId){
// Announcements
$announcementData = [
- 'headline' => 'Formulir ajuan kerjasama '. $proposal->cooperation->name .' telah disetujui',
- 'content' => 'Admin telah menyetujui formulir pengajuan kerjasama Anda.
- Sekarang, kerjasama ini sudah tersedia di menu Kerjasama. Harap tunggu hingga Admin menerbitkan Media Order.
',
+ 'headline' => 'Formulir ajuan kerja sama '. $proposal->cooperation->name .' telah disetujui',
+ 'content' => 'Admin telah menyetujui formulir pengajuan kerja sama Anda.
+ Sekarang, kerja sama ini sudah tersedia di menu Kerja Sama. Harap tunggu hingga Admin menerbitkan Media Order.
',
'enhancer_id' => Auth::id()
];
$createdAnnouncement = Announcement::create($announcementData);
@@ -240,12 +240,12 @@ public function mediaProposalAccept($id, $proposalId){
// End Announcements
if ($acceptedProposal) {
- return redirect()->back()->with('success-status', 'Berhasil menyetujui pengajuan kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menyetujui pengajuan kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal menyetujui pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menyetujui pengajuan kerja sama');
}
}catch(\Exception $e){
- return redirect()->back()->with('failed-status', 'Gagal menyetujui pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menyetujui pengajuan kerja sama');
}
}
@@ -254,7 +254,7 @@ public function mediaProposalReject($id, $proposalId){
$proposal = CooperationProposal::with(['cooperation', 'media', 'journalists'])->findOrFail(decrypt_id($proposalId));
return view('dashboard.media-cooperations.media-proposals.reject',[
- 'title' => 'Tolak Ajuan Kerjasama',
+ 'title' => 'Tolak Ajuan Kerja Sama',
'proposal' => $proposal
]);
}
@@ -277,8 +277,8 @@ public function mediaProposalRejectAction(Request $request, $id, $proposalId){
// Announcements
$announcementData = [
- 'headline' => 'Formulir ajuan kerjasama '. $proposal->cooperation->name .' ditolak',
- 'content' => 'Admin telah menolak formulir pengajuan kerjasama Anda.
+ 'headline' => 'Formulir ajuan kerja sama '. $proposal->cooperation->name .' ditolak',
+ 'content' => '
Admin telah menolak formulir pengajuan kerja sama Anda.
Alasan penolakan:
'.$validatedData['rejection_reason'].'
',
@@ -289,12 +289,12 @@ public function mediaProposalRejectAction(Request $request, $id, $proposalId){
// End Announcements
if ($rejectedProposal) {
- return redirect()->back()->with('success-status', 'Berhasil menolak pengajuan kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menolak pengajuan kerja sama.');
} else {
- return redirect()->back()->with('failed-status', 'Gagal menolak pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menolak pengajuan kerja sama');
}
}catch(\Exception $e){
- return redirect()->back()->with('failed-status', 'Gagal menolak pengajuan kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menolak pengajuan kerja sama');
}
}
@@ -335,9 +335,9 @@ public function process($id, $process, $paramMediaId = null){
$data['isHaveReports'] = false;
}
- // Tab Kerjasama
+ // Tab Kerja Sama
if($process === 'cooperation'){
- $data['title'] = 'Detail Kerjasama';
+ $data['title'] = 'Detail Kerja Sama';
if(is_role(['3'])){
$mediaOrderSafe = $data['mediaOrder'] ? $data['mediaOrder']->media->where('id', $data['mediaId'])->first() : null;
@@ -575,16 +575,16 @@ public function destroy($id){
return response()->json([
'status' => 'success',
- 'message' => 'Ajuan kerjasama dan semua media berhasil dihapus.'
+ 'message' => 'Ajuan kerja sama dan semua media berhasil dihapus.'
]);
}else{
- return response()->json(['message' => 'Kerjasama sudah memiliki media order.'], 500);
+ return response()->json(['message' => 'Kerja Sama sudah memiliki media order.'], 500);
}
}catch(\Exception $e){
- return response()->json(['message' => 'Gagal menghapus ajuan kerjasama.'], 500);
+ return response()->json(['message' => 'Gagal menghapus ajuan kerja sama.'], 500);
}
// return response()->json([
diff --git a/app/Http/Controllers/Dashboard/MediaOrderController.php b/app/Http/Controllers/Dashboard/MediaOrderController.php
index b015536..7c74cbb 100644
--- a/app/Http/Controllers/Dashboard/MediaOrderController.php
+++ b/app/Http/Controllers/Dashboard/MediaOrderController.php
@@ -51,8 +51,8 @@ public function store(OrderRequest $request, $id){
}
$announcementData = [
- 'headline' => 'Admin telah menerbitkan media order kerjasama '. $cooperation->name .'
',
- 'content' => 'Admin telah menerbitkan media order kerjasama '.$cooperation->name.'
',
+ 'headline' => 'Admin telah menerbitkan media order kerja sama '. $cooperation->name .'
',
+ 'content' => 'Admin telah menerbitkan media order kerja sama '.$cooperation->name.'
',
'enhancer_id' => Auth::id()
];
$createdAnnouncement = Announcement::create($announcementData);
@@ -144,8 +144,8 @@ public function accept(Request $request, $id){
// Announcements
$announcementData = [
- 'headline' => 'Media '.$mediaOrder->name.' telah menerima media order kerjasama '.$order->cooperation->name. '',
- 'content' => 'Media '.$mediaOrder->name.' telah menerima media order kerjasama '.$order->cooperation->name.'',
+ 'headline' => 'Media '.$mediaOrder->name.' telah menerima media order kerja sama '.$order->cooperation->name. '',
+ 'content' => 'Media '.$mediaOrder->name.' telah menerima media order kerja sama '.$order->cooperation->name.'',
'enhancer_id' => Auth::id()
];
@@ -163,7 +163,7 @@ public function accept(Request $request, $id){
return redirect()->back()->with('failed-status', 'Gagal menerima media order.');
}
} else {
- return redirect()->back()->with('failed-status', 'Kerjasama sudah diterima sebelumnya.');
+ return redirect()->back()->with('failed-status', 'Kerja sama sudah diterima sebelumnya.');
}
}
@@ -194,8 +194,8 @@ public function reject(Request $request, $id){
// Announcements
$announcementData = [
- 'headline' => 'Media '.$mediaOrder->name.' menolak media order kerjasama '.$order->cooperation->name. '',
- 'content' => 'Media '.$mediaOrder->name.' menolak media order kerjasama '.$order->cooperation->name.'
+ 'headline' => 'Media '.$mediaOrder->name.' menolak media order kerja sama '.$order->cooperation->name. '',
+ 'content' => 'Media '.$mediaOrder->name.' menolak media order kerja sama '.$order->cooperation->name.'
Alasan:
'.$validatedData['rejection_reason'].'
',
'enhancer_id' => Auth::id()
@@ -215,7 +215,7 @@ public function reject(Request $request, $id){
return redirect()->back()->with('failed-status', 'Gagal menolak media order.');
}
} else {
- return redirect()->back()->with('failed-status', 'Kerjasama sudah diterima sebelumnya.');
+ return redirect()->back()->with('failed-status', 'Kerja sama sudah diterima sebelumnya.');
}
}catch(\Exception $e){
return redirect()->back()->with('failed-status', 'Gagal menolak media order.');
diff --git a/app/Http/Controllers/Dashboard/OverviewController.php b/app/Http/Controllers/Dashboard/OverviewController.php
index 9c3c5a5..e9dff14 100644
--- a/app/Http/Controllers/Dashboard/OverviewController.php
+++ b/app/Http/Controllers/Dashboard/OverviewController.php
@@ -39,14 +39,14 @@ public function index(Request $request){
})
->get();
- // Data pengajuan kerjasama
+ // Data pengajuan kerja sama
$data['cooperationRequests'] = $media->cooperations()
->where(function ($query) {
$query->where('media_cooperations.status', '=', '0');
})
->get();
- // Data kalender Kerjasama
+ // Data kalender Kerja sama
$data['cooperationMedia'] = $media->cooperations->filter(function ($cooperation) use ($mediaId){
return $cooperation->proposals->where('status', 1)->where('media_id', $mediaId)->isNotEmpty();
});
@@ -142,7 +142,7 @@ public function index(Request $request){
- // Data kalender pengajuan kerjasama
+ // Data kalender pengajuan kerja sama
$data['cooperationRequests'] = Cooperation::all();
// Data kalender media order
@@ -150,7 +150,7 @@ public function index(Request $request){
}else if(is_role(['5'])){
- // Statistik Penyelesaian Kerjasama
+ // Statistik Penyelesaian Kerja sama
$cooperationCompletion = CooperationCompletion::all();
$cooperationCompletionCounts = $cooperationCompletion->groupBy('status')->map(function ($group) {
return $group->count();
diff --git a/app/Http/Controllers/Dashboard/ReportController.php b/app/Http/Controllers/Dashboard/ReportController.php
index b527b46..43dca5f 100644
--- a/app/Http/Controllers/Dashboard/ReportController.php
+++ b/app/Http/Controllers/Dashboard/ReportController.php
@@ -106,7 +106,7 @@ public function showIndex($id){
$report = Report::findOrFail(decrypt_id($id));
return view('dashboard.reports.index.show', [
- 'title' => 'Detail Penyelesaian Kerjasama',
+ 'title' => 'Detail Penyelesaian Kerja Sama',
'report' => $report
]);
}
@@ -115,7 +115,7 @@ public function processIndex($id){
$report = Report::findOrFail(decrypt_id($id));
return view('dashboard.reports.index.process', [
- 'title' => 'Detail Penyelesaian Kerjasama',
+ 'title' => 'Detail Penyelesaian Kerja Sama',
'report' => $report
]);
}
@@ -129,7 +129,7 @@ public function accept($id){
// Announcements
$announcementData = [
- 'headline' => 'Laporan bukti tayang kerjasama '. $report->order->cooperation->name .' telah disetujui',
+ 'headline' => 'Laporan bukti tayang kerja sama '. $report->order->cooperation->name .' telah disetujui',
'content' => 'Admin telah menyetujui laporan bukti tayang Anda.
',
'enhancer_id' => Auth::id()
];
@@ -171,7 +171,7 @@ public function rejectAction(Request $request, $mediaOrderId, $id){
// Announcements
$announcementData = [
- 'headline' => 'Laporan bukti tayang kerjasama '. $report->order->cooperation->name .' telah ditolak',
+ 'headline' => 'Laporan bukti tayang kerja sama '. $report->order->cooperation->name .' telah ditolak',
'content' => 'Admin telah menolak laporan bukti tayang Anda.
',
'enhancer_id' => Auth::id()
];
@@ -206,7 +206,7 @@ public function rejectActionIndex(Request $request, $id){
// Announcements
$announcementData = [
- 'headline' => 'Laporan bukti tayang kerjasama '. $report->order->cooperation->name .' telah ditolak',
+ 'headline' => 'Laporan bukti tayang kerja sama '. $report->order->cooperation->name .' telah ditolak',
'content' => 'Admin telah menolak laporan bukti tayang Anda.
',
'enhancer_id' => Auth::id()
];
diff --git a/app/Http/Requests/CooperationRequest.php b/app/Http/Requests/CooperationRequest.php
index 7aedec6..fd3f5a9 100644
--- a/app/Http/Requests/CooperationRequest.php
+++ b/app/Http/Requests/CooperationRequest.php
@@ -72,7 +72,7 @@ public function messages(): array
'offer_file_template.mimes' => 'Format file template harus PDF.',
'offer_file_template.max' => 'Ukuran file template maksimal 2MB.',
- 'description.required' => 'Deskripsi kerjasama wajib diisi.',
+ 'description.required' => 'Deskripsi kerja sama wajib diisi.',
];
}
diff --git a/database/settings/2025_02_27_064111_app_settings.php b/database/settings/2025_02_27_064111_app_settings.php
index e519787..81cc204 100644
--- a/database/settings/2025_02_27_064111_app_settings.php
+++ b/database/settings/2025_02_27_064111_app_settings.php
@@ -23,6 +23,6 @@ public function up(): void
$this->migrator->add('app.contact_whatsapp', null);
$this->migrator->add('app.contact_telegram', null);
$this->migrator->add('app.about_us', 'Sistem Media Komunikasi (SIMEDKOM) merupakan sebuah aplikasi berbasis digital untuk mempermudah bidang informasi dan komunikasi publik di Diskominfo Purwakarta dalam menjalankan monitoring media di Kabupaten Purwakarta.
- Aplikasi ini digunakan untuk penertiban administrasi kerjasama antara media dan pemerintah kabupaten Purwakarta yang dikoordinir oleh Diskominfo Purwakarta, juga menjadi alat filter dalam proses monitoring isu konten media terkait pemberitaan di Kabupaten Purwakarta.');
+ Aplikasi ini digunakan untuk penertiban administrasi kerja sama antara media dan pemerintah kabupaten Purwakarta yang dikoordinir oleh Diskominfo Purwakarta, juga menjadi alat filter dalam proses monitoring isu konten media terkait pemberitaan di Kabupaten Purwakarta.');
}
};
diff --git a/resources/views/dashboard/announcements/create.blade.php b/resources/views/dashboard/announcements/create.blade.php
index a2e2210..c4f99ae 100644
--- a/resources/views/dashboard/announcements/create.blade.php
+++ b/resources/views/dashboard/announcements/create.blade.php
@@ -19,7 +19,7 @@
diff --git a/app/Http/Controllers/Dashboard/CooperationCompletionController.php b/app/Http/Controllers/Dashboard/CooperationCompletionController.php
index 444c2dd..d99441a 100644
--- a/app/Http/Controllers/Dashboard/CooperationCompletionController.php
+++ b/app/Http/Controllers/Dashboard/CooperationCompletionController.php
@@ -18,10 +18,10 @@
class CooperationCompletionController extends Controller
{
// Main page: Penyelesaian Kerjasama
public function index(Request $request){
return view('dashboard.cooperation-completions.index', [
- 'title' => 'Penyelesaian Kerjasama',
+ 'title' => 'Penyelesaian Kerja Sama',
'mediaCollection' => Media::all(),
'media' => $request->input('media', []),
'status' => $request->input('status', null),
@@ -67,7 +67,7 @@ public function show($mediaOrderId, $id){
$cooperationCompletion = CooperationCompletion::findOrFail(decrypt_id($id));
return view('dashboard.cooperation-completions.show', [
- 'title' => 'Detail Penyelesaian Kerjasama',
+ 'title' => 'Detail Penyelesaian Kerja Sama',
'cooperationCompletion' => $cooperationCompletion,
'mediaOrderId' => $mediaOrderId
]);
@@ -77,7 +77,7 @@ public function showIndex($id){
$cooperationCompletion = CooperationCompletion::findOrFail(decrypt_id($id));
return view('dashboard.cooperation-completions.index.show', [
- 'title' => 'Detail Penyelesaian Kerjasama',
+ 'title' => 'Detail Penyelesaian Kerja Sama',
'cooperationCompletion' => $cooperationCompletion
]);
}
@@ -86,7 +86,7 @@ public function processIndex($id){
$cooperationCompletion = CooperationCompletion::findOrFail(decrypt_id($id));
return view('dashboard.cooperation-completions.index.process', [
- 'title' => 'Detail Penyelesaian Kerjasama',
+ 'title' => 'Detail Penyelesaian Kerja Sama',
'cooperationCompletion' => $cooperationCompletion
]);
}
@@ -102,8 +102,8 @@ public function accept($id){
// Announcements
$announcementData = [
- 'headline' => 'Formulir penyelesaian kerjasama '. $completion->order->cooperation->name .' telah disetujui',
- 'content' => 'Admin telah menyetujui laporan formulir penyelesaian kerjasama Anda.
',
+ 'headline' => 'Formulir penyelesaian kerja sama '. $completion->order->cooperation->name .' telah disetujui',
+ 'content' => 'Admin telah menyetujui laporan formulir penyelesaian kerja sama Anda.
',
'enhancer_id' => Auth::id()
];
@@ -113,10 +113,10 @@ public function accept($id){
}catch(\Exception $e){
Log::error("CooperationCompletions (accept): ". $e);
- return redirect()->back()->with('failed-status', 'Gagal menyetujui penyelesaian kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menyetujui penyelesaian kerja sama');
}
- return redirect()->back()->with('success-status', 'Berhasil menyetujui penyelesaian kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menyetujui penyelesaian kerja sama.');
}
@@ -124,7 +124,7 @@ public function reject($mediaOrderId, $id){
$cooperationCompletion = CooperationCompletion::findOrFail(decrypt_id($id));
return view('dashboard.cooperation-completions.reject', [
- 'title' => 'Tolak Penyelesaian Kerjasama',
+ 'title' => 'Tolak Penyelesaian Kerja Sama',
'cooperationCompletion' => $cooperationCompletion,
'mediaOrderId' => $mediaOrderId
]);
@@ -148,8 +148,8 @@ public function rejectAction(Request $request, $mediaOrderId, $id){
// Announcements
$announcementData = [
- 'headline' => 'Formulir penyelesaian kerjasama '. $completion->order->cooperation->name .' telah ditolak',
- 'content' => 'Admin telah menolak laporan formulir penyelesaian kerjasama Anda.
',
+ 'headline' => 'Formulir penyelesaian kerja sama '. $completion->order->cooperation->name .' telah ditolak',
+ 'content' => 'Admin telah menolak laporan formulir penyelesaian kerja sama Anda.
',
'enhancer_id' => Auth::id()
];
$createdAnnouncement = Announcement::create($announcementData);
@@ -158,10 +158,10 @@ public function rejectAction(Request $request, $mediaOrderId, $id){
}catch(\Exception $e){
Log::error("CooperationCompletions (rejectAction): ". $e);
- return redirect()->back()->with('failed-status', 'Gagal menolak penyelesaian kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menolak penyelesaian kerja sama');
}
- return redirect()->back()->with('success-status', 'Berhasil menolak penyelesaian kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menolak penyelesaian kerja sama.');
}
@@ -183,8 +183,8 @@ public function rejectActionIndex(Request $request, $id){
// Announcements
$announcementData = [
- 'headline' => 'Formulir penyelesaian kerjasama '. $completion->order->cooperation->name .' telah ditolak',
- 'content' => 'Admin telah menolak laporan formulir penyelesaian kerjasama Anda.
',
+ 'headline' => 'Formulir penyelesaian kerja sama '. $completion->order->cooperation->name .' telah ditolak',
+ 'content' => 'Admin telah menolak laporan formulir penyelesaian kerja sama Anda.
',
'enhancer_id' => Auth::id()
];
$createdAnnouncement = Announcement::create($announcementData);
@@ -193,10 +193,10 @@ public function rejectActionIndex(Request $request, $id){
}catch(\Exception $e){
Log::error("CooperationCompletions (rejectAction): ". $e);
- return redirect()->back()->with('failed-status', 'Gagal menolak penyelesaian kerjasama');
+ return redirect()->back()->with('failed-status', 'Gagal menolak penyelesaian kerja sama');
}
- return redirect()->back()->with('success-status', 'Berhasil menolak penyelesaian kerjasama.');
+ return redirect()->back()->with('success-status', 'Berhasil menolak penyelesaian kerja sama.');
}
@@ -18,10 +18,10 @@
class CooperationCompletionController extends Controller
{
- // Main page: Penyelesaian Kerjasama
+ // Main page: Penyelesaian Kerja Sama
public function index(Request $request){
return view('dashboard.cooperation-completions.index', [
diff --git a/app/Http/Controllers/Dashboard/DatatableController.php b/app/Http/Controllers/Dashboard/DatatableController.php
index db595f7..ab9ea53 100644
--- a/app/Http/Controllers/Dashboard/DatatableController.php
+++ b/app/Http/Controllers/Dashboard/DatatableController.php
@@ -1400,7 +1400,7 @@ public function journalistSubmission(Request $request, $role){
}
- // admin (kerjasama)
+ // admin (kerja sama)
public function cooperation(Request $request){
if ($request->ajax()) {
@@ -1466,7 +1466,7 @@ public function cooperation(Request $request){
if ($isHaveMediaOrder) {
return 'Media Order
Sudah Media Order';
}else{
- return 'Pengajuan Kerjasama
Belum Media Order';
+ return 'Pengajuan Kerja Sama
Belum Media Order';
}
})
->addColumn('action', function ($data) {
@@ -1514,7 +1514,7 @@ public function cooperation(Request $request){
}
if (is_role([1])) {
- $dropdown .= 'Hapus';
+ $dropdown .= 'Hapus';
}
@@ -1533,7 +1533,7 @@ public function cooperation(Request $request){
}
// admin (detail kerjasama -> data media)
public function cooperationMedia(Request $request, $id){
if ($request->ajax()) {
$cooperation = Cooperation::with(['media'])->where('id', '=', decrypt_id($id))->first();
@@ -1594,7 +1594,7 @@ class="text-dark"
}
- // admin (data pengajuan kerjasama)
+ // admin (data pengajuan kerja sama)
public function cooperationProposal(Request $request, $id){
if ($request->ajax()) {
@@ -1637,7 +1637,7 @@ public function cooperationProposal(Request $request, $id){
Detail';
if (is_role(['1']) && $data->status === '0') {
- $dropdown .= 'Terima';
+ $dropdown .= 'Terima';
}
if (is_role([1]) && $data->status === '0') {
@@ -1659,7 +1659,7 @@ public function cooperationProposal(Request $request, $id){
}
- // media (ajuan kerjasama)
+ // media (ajuan kerja sama)
public function cooperationRequest(Request $request){
if ($request->ajax()) {
@@ -1743,11 +1743,11 @@ public function cooperationRequest(Request $request){
->where('media_id', '=', Auth::user()->company->media->id)->exists();
if (is_role(['3']) && $data->pivot->status === '1' && !$isCooperationProposalExists) {
- $dropdown .= 'Ajukan Kerjasama';
+ $dropdown .= 'Ajukan Kerja Sama';
}
if (is_role(['3']) && $data->pivot->status === '0') {
- $dropdown .= 'Terima';
+ $dropdown .= 'Terima';
}
if (is_role(['3']) && $data->pivot->status === '0') {
@@ -1832,7 +1832,7 @@ public function mediaProposal(Request $request){
}
if (is_role(['3']) && $data->status === '0') {
- $dropdown .= 'Hapus';
+ $dropdown .= 'Hapus';
}
$dropdown .= '
@@ -2100,7 +2100,7 @@ class="text-dark"
Detail';
if (is_role(['1']) && $data->status === '0') {
- $dropdown .= 'Terima';
+ $dropdown .= 'Terima';
}
if (is_role(['1']) && $data->status === '0') {
@@ -2122,7 +2122,7 @@ class="text-dark"
}
- // Penyelesaian Kerjasama
+ // Penyelesaian Kerja sama
public function cooperationCompletionIndex(Request $request){
if ($request->ajax()) {
@@ -2225,7 +2225,7 @@ class="text-dark"
Detail';
// if (is_role(['1']) && $data->status === '0') {
- // $dropdown .= 'Terima';
+ // $dropdown .= 'Terima';
// }
if (is_role(['1', '5']) && $data->status === '0') {
@@ -2356,7 +2356,7 @@ class="text-dark"
Detail';
// if (is_role(['1']) && $data->status === '0') {
- // $dropdown .= 'Terima';
+ // $dropdown .= 'Terima';
// }
if (is_role(['1', '5'])) {
@@ -2444,7 +2444,7 @@ public function cooperationArchive(Request $request){
if ($isHaveMediaOrder) {
return 'Media Order
Sudah Media Order';
}else{
- return 'Pengajuan Kerjasama
Belum Media Order';
+ return 'Pengajuan Kerja Sama
Belum Media Order';
}
})
->addColumn('action', function ($data) {
@@ -1533,7 +1533,7 @@ public function cooperation(Request $request){
}
- // admin (detail kerjasama -> data media)
+ // admin (detail kerja sama -> data media)
public function cooperationMedia(Request $request, $id){
if ($request->ajax()) {